@@ -1,8 +1,12 @@
 from importlib import metadata
+from pathlib import Path
 import os
 import re
 import sys
 
+ROOT = Path(__file__).parent.parent
+PACKAGE_SRC = ROOT / "jsonschema"
+
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
@@ -25,9 +29,11 @@ extensions = [
     "sphinx.ext.intersphinx",
     "sphinx.ext.napoleon",
     "sphinx.ext.viewcode",
+
+    "autoapi.extension",
     "sphinx_autodoc_typehints",
+    "sphinx_json_schema_spec",
     "sphinxcontrib.spelling",
-    "jsonschema_role",
 ]
 
 cache_path = "_cache"
@@ -72,7 +78,8 @@ exclude_patterns = ["_build", "_cache", "_static", "_templates"]
 default_role = "any"
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = "sphinx"
+pygments_style = "lovelace"
+pygments_dark_style = "one-dark"
 
 # A list of ignored prefixes for module index sorting.
 # modindex_common_prefix = []
@@ -83,6 +90,7 @@ from jsonschema import *
 
 intersphinx_mapping = {
     "python": ("https://docs.python.org/3", None),
+    "ujs": ("https://json-schema.org/understanding-json-schema/", None),
 }
 
 
@@ -252,3 +260,27 @@ autosectionlabel_prefix_document = True
 # -- Options for sphinxcontrib-spelling -----------------------------------
 
 spelling_word_list_filename = "spelling-wordlist.txt"
+
+# -- Options for autoapi --------------------------------------------------
+
+suppress_warnings = [
+    "autoapi.python_import_resolution",
+    "autoapi.toc_reference",
+]
+autoapi_root = "api"
+autoapi_ignore = [
+    "*/_[a-z]*.py",
+    "*/__main__.py",
+    "*/benchmarks/*",
+    "*/cli.py",
+    "*/tests/*",
+]
+autoapi_options = [
+    "members",
+    "undoc-members",
+    "show-module-summary",
+    "imported-members",
+]
+
+autoapi_type = "python"
+autoapi_dirs = [PACKAGE_SRC]
